B class

Inheritance
Implemented types

Constructors

B({NodeElement? child, List<NodeElement>? children, String? accesskey, bool autofocus = false, List<StyleClass>? classList, bool contentEditable = false, String? contextmenu, String? dir, bool hidden = false, String? id, String? lang, String? role, bool spellcheck = false, List<StyleCSS>? styleList, int? tabindex, String? title, String? onblur, String? onchange, String? onclick, String? ondblclick, String? onfocus, String? onkeydown, String? onkeypress, String? onkeyup, String? onload, String? onmousedown, String? onmousemove, String? onmouseout, String? onmouseover, String? onmouseup, String? onreset, String? onselect, String? onsubmit, String? onunload})
const

Properties

accesskey → String?
final
autofocus → bool
final
child → NodeElement?
finalinherited
children → List<NodeElement>?
finalinherited
classList → List<StyleClass>?
final
contentEditable → bool
final
contextmenu → String?
final
dir → String?
final
hashCode → int
The hash code for this object.
no setterinherited
hidden → bool
final
id → String?
final
lang → String?
final
onblur → String?
final
onchange → String?
final
onclick → String?
final
ondblclick → String?
final
onfocus → String?
final
onkeydown → String?
final
onkeypress → String?
final
onkeyup → String?
final
onload → String?
final
onmousedown → String?
final
onmousemove → String?
final
onmouseout → String?
final
onmouseover → String?
final
onmouseup → String?
final
onreset → String?
final
onselect → String?
final
onsubmit → String?
final
onunload → String?
final
role → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spellcheck → bool
final
styleList → List<StyleCSS>?
final
tabindex → int?
final
title → String?
final

Methods

build() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited